-- this file contains settings and constants for use within the game that will be changed often.
-- this file also contains functionality for saving and loading settings from the registry using the registry edit game utility

-- initial game settings

--[[
	These settings are gathered up by WndNfo
	They are globally accessable through that static 
	class, so no need to fetch them from here.
--]]
screenwidth		=				1024
screenheight		=				768
fullscreen		=				1 --0
vsync			=				0
xpos			=				0
ypos			=				0

-- shaders?
menushaders		=				1

-- resource paths
MODEL_PATH		=				"../res/mdl/"
TEXTURE_PATH		=				"../res/tex/"
SCRIPTS_PATH		=				"../res/dat/"
SHADERS_PATH		=				"../res/dat/"

-- physics constants
RUNSPEED		=				13.0
JUMPSPEED		=				65.0
FRICTION		=				70.0
GRAVITYACCEL		=				150.0

-- bindable actions
ACTION_UP		=				0
ACTION_DOWN		=				1
ACTION_LEFT		=				2
ACTION_RIGHT		=				3
ACTION_JUMP		=				4
ACTION_GAME_QUIT	=				5
ACTION_WEAPON		=				6
ACTION_ATTACK		=				7
ACTIONS_COUNT		=				8
ACTIONS_TOGGLEMUSIC	=				9

-- registry editing constants
GAME_KEY		=				"Software\\They"
REG_SZ			=				1
REG_DWORD		=				4

function testSettings()
	openRegistryKey(GAME_KEY)
	result, test = readRegistryDW("screenheight")
	closeRegistryKey()
	if test > 0 and result then
		return true
	else
		return false
	end
end

function loadSettings()
	openRegistryKey(GAME_KEY)
	screenwidth = readRegistryDW("screenwidth")
	screenheight = readRegistryDW("screenheight")
	vsync = readRegistryDW("vsync")
	fullscreen	= readRegistryDW("fullscreen")
	xpos = readRegistryDW("xpos")
	ypos = readRegistryDW("ypos")
	closeRegistryKey()
end

function saveSettings()
	openRegistryKey(GAME_KEY)
	writeRegistryValue("screenwidth", REG_DWORD, screenwidth)
	writeRegistryValue("screenheight", REG_DWORD, screenheight)
	writeRegistryValue("vsync", REG_DWORD, vsync)
	writeRegistryValue("fullscreen", REG_DWORD, fullscreen)
	writeRegistryValue("xpos", REG_DWORD, xpos)
	writeRegistryValue("ypos", REG_DWORD, ypos)
	closeRegistryKey()
end